/*
 *=BEGIN GPL
 *
 * This file is part of the SiteProbeQt program.
 *
 * Copyright(c) 2010 Darrell Duffy
 * http://www.windyweather.net/wp
 *
 * This file may be licensed under the terms of of the
 * GNU General Public License Version 2 (the ``GPL'').
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the GPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the GPL along with this
 * program. If not, go to http://www.gnu.org/licenses/gpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *=END GPL
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QBasicTimer>
#include <QSettings>
#include <QFile>
#include <QAbstractSocket>
#include <QTcpSocket>

class QTreeWidgetItem;


namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

    void timerEvent(QTimerEvent *event);    // timer event comes here

private:
    Ui::MainWindow *ui;

    bool            m_bMonitoring;  // we are monitoring
    int             m_nTimer;       // timer code

    void setStatus( QString sts );

    QBasicTimer         m_timer;                // timer to monitor the sites

    QSettings*          m_pSettings;            // pointer to a settings file

    QString             m_sLogPath;             // path to the log file, in same place as settings

    QBasicTimer         m_logTimer;             // close the log after a while.
    QFile               m_fLogFile;             // the log file

    bool                m_bScanFirstTime;       // scan first time, we log everything
    bool                m_bScanActive;          // scan is active, so can't change modes.
    bool                m_bStopScan;            // stop the scan
    int                 m_nSiteIndex;           // index while we are monitoring
    QTcpSocket          m_tcpSocket;            // socket used for scan

    // save and restore the site list and the minutes
    void    createSettings();
    void    saveSettings();
    void    restoreSettings();

    // while we are monitoring, disable part of the GUI
    void    enableGui( bool bEnable );

    // Log support
    void    openLog();
    void    closeLog();
    void    logMessage( QString str );

    // scan the sites and update the data in the list
    // and log any changes.
    void    scanSites();
    void    nextSite();
    void    stopScan();
    void    logSiteChange( QTreeWidgetItem* pitem, QString sts );

    void    closeEvent ( QCloseEvent * event );

private slots:
    void on_actionTest_Failure_Columns_triggered();
    void on_actionClear_Selected_Failure_triggered();
    void on_actionClear_All_Failures_triggered();
    void on_actionTest_Log_File_triggered();
    void on_actionOpen_Log_triggered();
    void on_btnClose_clicked();
    void on_btnStopMonitoring_clicked();
    void on_btnStartMonitoring_clicked();
    void on_btnRemoveSite_clicked();
    void on_btnAddSite_clicked();
    void on_actionAbout_triggered();
    void on_actionQuit_triggered();


    // slots for site monitoring
    void siteConnected();
    void siteFailure(QAbstractSocket::SocketError socketError);

};

#endif // MAINWINDOW_H
