/*
 *=BEGIN GPL
 *
 * This file is part of the SiteProbeQt program.
 *
 * Copyright(c) 2010 Darrell Duffy
 * http://www.windyweather.net/wp
 *
 * This file may be licensed under the terms of of the
 * GNU General Public License Version 2 (the ``GPL'').
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the GPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the GPL along with this
 * program. If not, go to http://www.gnu.org/licenses/gpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 *=END GPL
 */

#include "viewlog.h"
#include "ui_viewlog.h"
#include <QFile>
#include <QTextStream>
#include <QFileDialog>
#include <QMessageBox>

ViewLog::ViewLog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::ViewLog)
{
    ui->setupUi(this);
}

ViewLog::~ViewLog()
{
    delete ui;
}

void ViewLog::on_btnClose_clicked()
{
    accept();
}

void ViewLog::setStatus( QString sts )
{
    ui->lbStatus->setText( sts );
}


void ViewLog::setLogPath( QString path )
{
    m_sLogPath = path;
    setStatus( path );
    // read the log and display it
    QFile   fLogFile;
    int     nLines(0);

    fLogFile.setFileName( path );

    if ( fLogFile.open( QIODevice::ReadOnly | QIODevice::Text) )
    {
        QTextStream instream( &fLogFile );

        QString str;

        while ( !instream.atEnd() )
        {
            str = instream.readLine() ; //+ QString("\n");
            ui->teLog->appendPlainText( str );
            nLines++;
        }
        fLogFile.close();
    }
    if ( nLines )
    {
        setStatus( tr("Read %1 Log Lines").arg(nLines) );
    }
    else
    {
        setStatus(tr("No lines in log"));
    }

}


void ViewLog::on_btnClearLog_clicked()
{

    QMessageBox msgBox;
    msgBox.setText( tr("Clear the SiteProbeQt Log?") );
    msgBox.setInformativeText(tr("This cannot be undone.") );
    msgBox.setStandardButtons(QMessageBox::Ok | QMessageBox::Cancel );
    msgBox.setDefaultButton(QMessageBox::Cancel);
    msgBox.setIcon(QMessageBox::Warning);
    int ret = msgBox.exec();
    if ( ret != QMessageBox::Ok )
    {
        setStatus(tr("Log Not Cleared"));
        return;
    }

    QFile fLogFile;

    fLogFile.setFileName( m_sLogPath );
    if ( !fLogFile.open( QIODevice::WriteOnly | QIODevice::Text ) )
    {
        setStatus(tr("Difficulty opening log file"));
        return;
    }
    else
    {
        // Just close with no contents.
        fLogFile.close();
        ui->teLog->clear();
        setStatus(tr("Log file cleared."));
    }
}

void ViewLog::on_btnSaveLog_clicked()
{
    //QString 	getSaveFileName ( QWidget * parent = 0, const QString & caption = QString(),
    //const QString & dir = QString(), const QString & filter = QString(), QString * selectedFilter = 0,
    //Options options = 0 )

    QString sSaveLogPath = QFileDialog::getSaveFileName( this, tr("Save Log File"), QString(),
                                                         "Text (*.txt);;CSV (*.csv)");
    if ( sSaveLogPath.count() )
    {
        QFile   fFile;
        fFile.setFileName( sSaveLogPath );
        fFile.open( QIODevice::Text | QIODevice::WriteOnly );

        QTextStream out(&fFile);

        out << ui->teLog->toPlainText();
        fFile.close();
    }
}
